summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvassprite_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvassprite_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvassprite_imp.cpp128
1 files changed, 64 insertions, 64 deletions
diff --git a/kjsembed/qtbindings/qcanvassprite_imp.cpp b/kjsembed/qtbindings/qcanvassprite_imp.cpp
index 7d9898b3..d4c8dc23 100644
--- a/kjsembed/qtbindings/qcanvassprite_imp.cpp
+++ b/kjsembed/qtbindings/qcanvassprite_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasSpriteImp::QCanvasSpriteImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasSpriteImp::TQCanvasSpriteImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasSpriteImp::~QCanvasSpriteImp()
+TTQCanvasSpriteImp::~TQCanvasSpriteImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasSpriteImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasSpriteImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasSpriteImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasSpriteImp *meth = new QCanvasSpriteImp( exec, methods[idx].id );
+ TQCanvasSpriteImp *meth = new TQCanvasSpriteImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -66,8 +66,8 @@ void QCanvasSpriteImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
EnumValue enums[] = {
// enum FrameAnimationType
- { "Cycle", TQCanvasSprite::Cycle },
- { "Oscillate", TQCanvasSprite::Oscillate },
+ { "Cycle", TTQCanvasSprite::Cycle },
+ { "Oscillate", TTQCanvasSprite::Oscillate },
{ 0, 0 }
};
@@ -82,7 +82,7 @@ void QCanvasSpriteImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasSpriteImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasSpriteImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -115,11 +115,11 @@ void QCanvasSpriteImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasSpriteImp *meth = new QCanvasSpriteImp( exec, methods[idx].id );
+ TQCanvasSpriteImp *meth = new TQCanvasSpriteImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -128,64 +128,64 @@ void QCanvasSpriteImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TQCanvasSprite pointer from an Object.
*/
-TQCanvasSprite *QCanvasSpriteImp::toQCanvasSprite( KJS::Object &self )
+TTQCanvasSprite *TQCanvasSpriteImp::toTQCanvasSprite( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasSprite *>( obj );
+ return dynamic_cast<TTQCanvasSprite *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasSprite" )
+ if ( op->typeName() != "TTQCanvasSprite" )
return 0;
- return op->toNative<TQCanvasSprite>();
+ return op->toNative<TTQCanvasSprite>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasSpriteImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasSpriteImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QCanvasSprite_1:
- return QCanvasSprite_1( exec, args );
+ return TQCanvasSprite_1( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QCanvasSpriteCons has no constructor with id '%1'.").arg(id);
+ TTQString msg = i18n("TQCanvasSpriteCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QCanvasSpriteImp::QCanvasSprite_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasSpriteImp::TQCanvasSprite_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TQCanvasPixmapArray *
return KJS::Object();
- TQCanvasPixmapArray * arg0; // Dummy
+ TTQCanvasPixmapArray * arg0; // Dummy
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();
- TQCanvas * arg1; // Dummy
+ TTQCanvas * arg1; // Dummy
- // We should now create an instance of the TQCanvasSprite object
+ // We should now create an instance of the TTQCanvasSprite object
- TQCanvasSprite *ret = new TQCanvasSprite(
+ TTQCanvasSprite *ret = new TTQCanvasSprite(
arg0,
arg1 );
@@ -193,9 +193,9 @@ KJS::Object QCanvasSpriteImp::QCanvasSprite_1( KJS::ExecState *exec, const KJS::
}
-KJS::Value QCanvasSpriteImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasSpriteImp::toQCanvasSprite( self );
+ instance = TQCanvasSpriteImp::toTQCanvasSprite( self );
switch( id ) {
@@ -303,18 +303,18 @@ KJS::Value QCanvasSpriteImp::call( KJS::ExecState *exec, KJS::Object &self, cons
break;
}
- TQString msg = i18n( "QCanvasSpriteImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasSpriteImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasSpriteImp::setSequence_2( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::setSequence_2( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TQCanvasPixmapArray *
return KJS::Value();
- TQCanvasPixmapArray * arg0; // Dummy
+ TTQCanvasPixmapArray * arg0; // Dummy
instance->setSequence(
arg0 );
@@ -322,7 +322,7 @@ KJS::Value QCanvasSpriteImp::setSequence_2( KJS::ExecState *exec, KJS::Object &o
}
-KJS::Value QCanvasSpriteImp::move_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::move_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
double arg0 = extractDouble(exec, args, 0);
@@ -336,7 +336,7 @@ KJS::Value QCanvasSpriteImp::move_4( KJS::ExecState *exec, KJS::Object &obj, con
}
-KJS::Value QCanvasSpriteImp::move_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::move_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
double arg0 = extractDouble(exec, args, 0);
@@ -353,7 +353,7 @@ KJS::Value QCanvasSpriteImp::move_5( KJS::ExecState *exec, KJS::Object &obj, con
}
-KJS::Value QCanvasSpriteImp::setFrame_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::setFrame_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -364,10 +364,10 @@ KJS::Value QCanvasSpriteImp::setFrame_6( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasSpriteImp::setFrameAnimation_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::setFrameAnimation_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQCanvasSprite::FrameAnimationType arg0 = TQCanvasSprite::Cycle; // TODO (hack for TQCanvasSprite)
+ TTQCanvasSprite::FrameAnimationType arg0 = TTQCanvasSprite::Cycle; // TODO (hack for TTQCanvasSprite)
int arg1 = extractInt(exec, args, 1);
@@ -381,7 +381,7 @@ KJS::Value QCanvasSpriteImp::setFrameAnimation_7( KJS::ExecState *exec, KJS::Obj
}
-KJS::Value QCanvasSpriteImp::frame_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::frame_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -390,7 +390,7 @@ KJS::Value QCanvasSpriteImp::frame_8( KJS::ExecState *exec, KJS::Object &obj, co
}
-KJS::Value QCanvasSpriteImp::frameCount_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::frameCount_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -399,7 +399,7 @@ KJS::Value QCanvasSpriteImp::frameCount_9( KJS::ExecState *exec, KJS::Object &ob
}
-KJS::Value QCanvasSpriteImp::rtti_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::rtti_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -408,13 +408,13 @@ KJS::Value QCanvasSpriteImp::rtti_10( KJS::ExecState *exec, KJS::Object &obj, co
}
-KJS::Value QCanvasSpriteImp::collidesWith_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::collidesWith_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const TQCanvasItem *
return KJS::Value();
- const TQCanvasItem * arg0; // Dummy
+ const TTQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -423,16 +423,16 @@ KJS::Value QCanvasSpriteImp::collidesWith_11( KJS::ExecState *exec, KJS::Object
}
-KJS::Value QCanvasSpriteImp::boundingRect_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::boundingRect_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQRect ret;
+ TTQRect ret;
ret = instance->boundingRect( );
return convertToValue( exec, ret );
}
-KJS::Value QCanvasSpriteImp::width_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::width_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -441,7 +441,7 @@ KJS::Value QCanvasSpriteImp::width_13( KJS::ExecState *exec, KJS::Object &obj, c
}
-KJS::Value QCanvasSpriteImp::height_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::height_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -450,7 +450,7 @@ KJS::Value QCanvasSpriteImp::height_14( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasSpriteImp::leftEdge_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::leftEdge_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -459,7 +459,7 @@ KJS::Value QCanvasSpriteImp::leftEdge_15( KJS::ExecState *exec, KJS::Object &obj
}
-KJS::Value QCanvasSpriteImp::topEdge_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::topEdge_16( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -468,7 +468,7 @@ KJS::Value QCanvasSpriteImp::topEdge_16( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasSpriteImp::rightEdge_17( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::rightEdge_17( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -477,7 +477,7 @@ KJS::Value QCanvasSpriteImp::rightEdge_17( KJS::ExecState *exec, KJS::Object &ob
}
-KJS::Value QCanvasSpriteImp::bottomEdge_18( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::bottomEdge_18( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -486,7 +486,7 @@ KJS::Value QCanvasSpriteImp::bottomEdge_18( KJS::ExecState *exec, KJS::Object &o
}
-KJS::Value QCanvasSpriteImp::leftEdge_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::leftEdge_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -498,7 +498,7 @@ KJS::Value QCanvasSpriteImp::leftEdge_19( KJS::ExecState *exec, KJS::Object &obj
}
-KJS::Value QCanvasSpriteImp::topEdge_20( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::topEdge_20( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -510,7 +510,7 @@ KJS::Value QCanvasSpriteImp::topEdge_20( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasSpriteImp::rightEdge_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::rightEdge_21( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -522,7 +522,7 @@ KJS::Value QCanvasSpriteImp::rightEdge_21( KJS::ExecState *exec, KJS::Object &ob
}
-KJS::Value QCanvasSpriteImp::bottomEdge_22( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::bottomEdge_22( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -534,34 +534,34 @@ KJS::Value QCanvasSpriteImp::bottomEdge_22( KJS::ExecState *exec, KJS::Object &o
}
-KJS::Value QCanvasSpriteImp::image_23( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::image_23( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->image( );
- return KJS::Value(); // Returns 'TQCanvasPixmap *'
+ return KJS::Value(); // Returns 'TTQCanvasPixmap *'
}
-KJS::Value QCanvasSpriteImp::imageAdvanced_24( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::imageAdvanced_24( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->imageAdvanced( );
- return KJS::Value(); // Returns 'TQCanvasPixmap *'
+ return KJS::Value(); // Returns 'TTQCanvasPixmap *'
}
-KJS::Value QCanvasSpriteImp::image_25( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::image_25( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
instance->image(
arg0 );
- return KJS::Value(); // Returns 'TQCanvasPixmap *'
+ return KJS::Value(); // Returns 'TTQCanvasPixmap *'
}
-KJS::Value QCanvasSpriteImp::advance_26( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::advance_26( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -572,10 +572,10 @@ KJS::Value QCanvasSpriteImp::advance_26( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasSpriteImp::draw_27( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasSpriteImp::draw_27( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQPainter arg0; // TODO (hack for qcanvas)
+ TTQPainter arg0; // TODO (hack for qcanvas)
instance->draw(
arg0 );
@@ -128,64 +128,64 @@ void QCanvasSpriteImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TQCanvasSprite pointer from an Object.
+ * Extract a TTQCanvasSprite pointer from an Object.
*/
@@ -128,64 +128,64 @@ void QCanvasSpriteImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
- // Unsupported parameter TQCanvasPixmapArray *
+ // Unsupported parameter TTQCanvasPixmapArray *
return KJS::Object();
@@ -303,18 +303,18 @@ KJS::Value QCanvasSpriteImp::call( KJS::ExecState *exec, KJS::Object &self, cons
{
- // Unsupported parameter TQCanvasPixmapArray *
+ // Unsupported parameter TTQCanvasPixmapArray *
return KJS::Value();
@@ -408,13 +408,13 @@ KJS::Value QCanvasSpriteImp::rtti_10( KJS::ExecState *exec, KJS::Object &obj, co
{
- // Unsupported parameter const TQCanvasItem *
+ // Unsupported parameter const TTQCanvasItem *
return KJS::Value();